==> nextcloud-app-contacts-3.1.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/es_CL.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "All contacts" : "Todos los contactos",
    "Details" : "Detalles",
    "Loading" : "Cargando",
    "Name" : "Nombre",
    "Title" : "Título",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Groups" : "Grupos",
    "New contact" : "Nuevo contacto",
    "No results" : "No hay resultados",
    "Last modified" : "Última modificación",
    "Rename" : "Renombrar",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "Copy link" : "Copiar liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Importing into" : "Importando a",
    "Import into" : "Importar a",
    "Address book name" : "Nombre de la libreta de direcciones",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Display name" : "Nombre a desplegar",
    "Not grouped" : "No agrupado",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Social network" : "Red social",
    "Relationship" : "Relación",
    "Specify a relationship between you and the entity represented by this vCard." : "Especifica la relación entre tú y la entidad representada por esta vCard.",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Manager" : "Gerente",
    "Assistant" : "Asistente",
    "Related" : "Relacionado",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Especifica la relación entre alguna otra entidad y la entidad representada por esta vCard.",
    "Contact" : "Contacto",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "None" : "Ninguno",
    "Unknown" : "Desconocido",
    "Timezone" : "Zona horaria"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-5.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/es_CL.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "Contacts" : "Contactos",
    "Loading contacts …" : "Cargando contactos ...",
    "Loading …" : "Cargando …",
    "Delete circle" : "Borrar círculo",
    "General settings" : "Configuraciones generales",
    "Download" : "Descargar",
    "Send email" : "Enviar correo electrónico",
    "Circles" : "Círculos",
    "Create a new circle" : "Crear un nuevo círculo",
    "Rename" : "Renombrar",
    "Enabled" : "Habilitado",
    "Delete" : "Borrar",
    "Copy link" : "Copiar liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Display name" : "Nombre a desplegar",
    "Last modified" : "Última modificación",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Description" : "Descripción",
    "Invalid image" : "Imagen inválida",
    "Name" : "Nombre",
    "Title" : "Título",
    "Cancel" : "Cancelar",
    "Address book" : "Libreta de direcciones",
    "New contact" : "Nuevo contacto",
    "Search contacts …" : "Buscar contactos ...",
    "No results" : "No hay resultados",
    "Personal circle" : "Círculo personal",
    "Pending" : "Pendiente",
    "Close" : "Cerrar",
    "Import" : "Importar",
    "Not grouped" : "No agrupado",
    "Circle" : "Círculo",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Admin",
    "Owner" : "Dueño",
    "Users" : "Ususarios",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Manager" : "Gerente",
    "Social network" : "Red social",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "None" : "Ninguno",
    "Unknown" : "Desconocido"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
